summaryrefslogtreecommitdiffstats
path: root/tdecore/kstaticdeleter.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:22 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:22 -0600
commit28edc0aa2ab09297288186f5bc15765eb7be58c0 (patch)
tree7b7a01768b3781763186c825af21bb14717d2c32 /tdecore/kstaticdeleter.h
parent07c48c43ff72c237e4028154f4594102b798073f (diff)
downloadtdelibs-28edc0aa2ab09297288186f5bc15765eb7be58c0.tar.gz
tdelibs-28edc0aa2ab09297288186f5bc15765eb7be58c0.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kstaticdeleter.h')
-rw-r--r--tdecore/kstaticdeleter.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/tdecore/kstaticdeleter.h b/tdecore/kstaticdeleter.h
index 61b4a8e4a..dd759adf7 100644
--- a/tdecore/kstaticdeleter.h
+++ b/tdecore/kstaticdeleter.h
@@ -27,14 +27,14 @@
/**
* Static deleters are used to manage static resources. They can register
* themselves with KGlobal. KGlobal will call destructObject() when
* KGlobal::deleteStaticDeleters() is called or when it the process
* finishes.
*
* @see KStaticDeleter
* @see KGlobal::registerStaticDeleter()
* @see KGlobal::unregisterStaticDeleter()
* @see KGlobal::deleteStaticDeleters()
*/
class TDECORE_EXPORT KStaticDeleterBase {
public:
@@ -42,7 +42,7 @@ public:
/**
* Should destruct the resources managed by this KStaticDeleterBase.
* Usually you also want to call it in your destructor.
- * @see KGlobal::deleteStaticDeleters()
+ * @see TDEGlobal::deleteStaticDeleters()
*/
virtual void destructObject();
};
@@ -76,7 +76,7 @@ public:
KStaticDeleter() { deleteit = 0; globalReference = 0; array = false; }
/**
* Sets the object to delete and registers the object to be
* deleted to KGlobal. If the given object is 0, the former
* registration is unregistered.
* @param obj the object to delete
* @param isArray tells the destructor to delete an array instead of an object
@@ -87,14 +87,14 @@ public:
globalReference = 0;
array = isArray;
if (obj)
- KGlobal::registerStaticDeleter(this);
+ TDEGlobal::registerStaticDeleter(this);
else
- KGlobal::unregisterStaticDeleter(this);
+ TDEGlobal::unregisterStaticDeleter(this);
return obj;
}
/**
* Sets the object to delete and registers the object to be
* deleted to KGlobal. If the given object is 0, the former
* registration is unregistered.
* @param globalRef the static pointer where this object is stored
* This pointer will be reset to 0 after deletion of the object.
@@ -106,9 +106,9 @@ public:
deleteit = obj;
array = isArray;
if (obj)
- KGlobal::registerStaticDeleter(this);
+ TDEGlobal::registerStaticDeleter(this);
else
- KGlobal::unregisterStaticDeleter(this);
+ TDEGlobal::unregisterStaticDeleter(this);
globalRef = obj;
return obj;
}
@@ -127,7 +127,7 @@ public:
deleteit = 0;
}
virtual ~KStaticDeleter() {
- KGlobal::unregisterStaticDeleter(this);
+ TDEGlobal::unregisterStaticDeleter(this);
destructObject();
}
private:
@@ -27,14 +27,14 @@
/**
* Static deleters are used to manage static resources. They can register
- * themselves with KGlobal. KGlobal will call destructObject() when
- * KGlobal::deleteStaticDeleters() is called or when it the process
+ * themselves with TDEGlobal. TDEGlobal will call destructObject() when
+ * TDEGlobal::deleteStaticDeleters() is called or when it the process
* finishes.
*
@@ -27,14 +27,14 @@
*
* @see KStaticDeleter
- * @see KGlobal::registerStaticDeleter()
- * @see KGlobal::unregisterStaticDeleter()
- * @see KGlobal::deleteStaticDeleters()
+ * @see TDEGlobal::registerStaticDeleter()
+ * @see TDEGlobal::unregisterStaticDeleter()
+ * @see TDEGlobal::deleteStaticDeleters()
*/
class TDECORE_EXPORT KStaticDeleterBase {
@@ -76,7 +76,7 @@ public:
/**
* Sets the object to delete and registers the object to be
- * deleted to KGlobal. If the given object is 0, the former
+ * deleted to TDEGlobal. If the given object is 0, the former
* registration is unregistered.
* @param obj the object to delete
@@ -87,14 +87,14 @@ public:
/**
* Sets the object to delete and registers the object to be
- * deleted to KGlobal. If the given object is 0, the former
+ * deleted to TDEGlobal. If the given object is 0, the former
* registration is unregistered.
* @param globalRef the static pointer where this object is stored